* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [AI Agent Discovery](https://help.sap.com/docs/leanix/ea/ai-agent-discovery)
  * Discovering AI Agents from Microsoft Entra ID
